==> openjdk-lts_11.0.7+10.orig.tar.xz: openjdk-11-11.0.7+10/src/jdk.crypto.ucrypto/solaris/classes/com/oracle/security/ucrypto/ServiceDesc.java <==
/*
 * Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package com.oracle.security.ucrypto;

import java.util.*;

/**
 * Class for encapsulating the type, algorithm, and class name of
 * a Provider.Service object.
 */
final class ServiceDesc {

    private final String type;
    private final String algo;
    private final String cn;
    private final List<String> aliases;

    ServiceDesc(String type, String algo, String cn) {
        this(type, algo, cn, null);
    }

    ServiceDesc(String type, String algo, String cn, String[] aliases) {
        this.type = type;
        this.algo = algo;
        this.cn = cn;
        if (aliases != null) {
            this.aliases = Arrays.asList(aliases);
        } else {
            this.aliases = null;
        }
    }
    String getType() {
        return type;
    }
    String getAlgorithm() {
        return algo;
    }
    String getClassName() {
        return cn;
    }
    List<String> getAliases() {
        return aliases;
    }
    public String toString() {
        return type + "." + algo + ": " + cn + ", aliases =" + aliases;
    }
}

==> openjdk-lts_11.0.23+9.orig.tar.xz: openjdk-11-11.0.23+9/src/jdk.crypto.ucrypto/solaris/classes/com/oracle/security/ucrypto/ServiceDesc.java <==
/*
 * Copyright (c) 2015, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package com.oracle.security.ucrypto;

import java.util.*;

/**
 * Class for encapsulating the type, algorithm, and class name of
 * a Provider.Service object.
 */
final class ServiceDesc {

    private final String type;
    private final String algo;
    private final String cn;
    private final List<String> aliases;

    ServiceDesc(String type, String algo, String cn) {
        this(type, algo, cn, null);
    }

    ServiceDesc(String type, String algo, String cn, List<String> aliases) {
        this.type = type;
        this.algo = algo;
        this.cn = cn;
        this.aliases = aliases;
    }
    String getType() {
        return type;
    }
    String getAlgorithm() {
        return algo;
    }
    String getClassName() {
        return cn;
    }
    List<String> getAliases() {
        return aliases;
    }
    public String toString() {
        return type + "." + algo + ": " + cn + ", aliases =" + aliases;
    }
}
